﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace WSUniversalLib
{
    /// <summary>
    /// Библиотека классов к основному проекту
    /// </summary>
    public class Calculation
    {
        //Коэффициенты типа продукции
        private static List<float> cProductType = new List<float>() { 1.1f, 2.5f, 8.43f };
        //процент брака материала
        private static List<float> procentDeffect = new List<float> { 0.003f, 0.0012f };
        /// <summary>
        /// Метод для для расчета целого количества сырья, необходимого  для производства определенного количества (count) продукции, учитывая возможный брак материалов. 
        /// </summary>
        /// <param name="productType">тип продукции</param>
        /// <param name="materialType">тип материала</param>
        /// <param name="count">количество изготовленной продукции</param>
        /// <param name="width">ширина продукции</param>
        /// <param name="length">длина продукции</param>
        /// <returns>количество сырья, необходимого для производства</returns>
        public static int GetQuantityForProduct(int productType, int materialType, int count, float width, float length)
        {
            //проверка на соответствие типа продукции
            if (productType <= 0 || productType > 3) return -1;
            //проверка на соответствие типа материала
            if (materialType <= 0 || materialType > 2) return -1;
            //проверка на корректность длины
            if (length <= 0f) return -1;
            //проверка на корректность ширирны
            if (width <= 0f) return -1;
            //проверка на корректность количества
            if(count <= 0f) return -1;
            //расчет материала
            float S = length * width; //площадь  еденицы продукции
            float c = cProductType[productType-1]; //коэффициент типа продукции
            float countMaterial = S * c; //Количество необходимого качественного сырья на одну единицу продукции
            float procent = procentDeffect[materialType-1]; //процент брака материала
            countMaterial *= count;//Количество необходимого качественного сырья на заданное количество продукции
            countMaterial += procent * countMaterial; //добавляем процент брака
            //считаем остатки от целого и взависимости от этого округляем
            if (countMaterial - (int)countMaterial > 0) return (int)countMaterial + 1;
            else return (int)countMaterial;
        }
    }
}
